@@ -1,5 +1,6 @@
 from .layers import *
 from .utils import *
+from .positional_encoders import *
 from .explainability import *
 from .FCN import *
 from .FCNPlus import *
@@ -7,6 +8,7 @@ from .TCN import *
 from .InceptionTime import *
 from .InceptionTimePlus import *
 from .MLP import *
+from .GatedTabTransformer import *
 from .gMLP import *
 from .mWDN import *
 from .OmniScaleCNN import *
@@ -37,5 +39,6 @@ from .TabTransformer import *
 from .TabFusionTransformer import *
 from .TSPerceiver import *
 from .TSiTPlus import *
+from .TSSequencerPlus import *
 from .MultiInputNet import *
 from .misc import *
\ No newline at end of file
